@@ -93,8 +93,11 @@ class Console:
 		except:
 			pass
 
-	def WriteLine(self, Message):
-		self.CommandList.insert(tk.END, Message)
+	# Log Commands
+	def Log(self, Message, LogPrefix="", color=None):
+		self.CommandList.insert(tk.END, LogPrefix + Message)
+		if color:
+			self.CommandList.itemconfig(tk.END, fg=color)
 
 	def Clear(self):
 		self.CommandList.delete(0, tk.END)
@@ -118,7 +121,7 @@ class Console:
 			if i.command.lower() == commandExecuting:
 				i.execute()
 				return
-		self.WriteLine(f"Command {commandExecuting} Doesn't Exist!")
+		self.Log(f"Command {commandExecuting} Doesn't Exist!", color='red')
 
 	def exit(self):
 		sys.exit()
@@ -132,7 +135,7 @@ class Console:
 		except TypeError:
 			self.RaiseError("Cannot Add A String To The Commands List. Did You Mean \"RegisterCommand\"?")
 
-	def RaiseError(error):
+	def RaiseError(self, error):
 		if self.Debug == True:
 			raise ConsoleError(error)
 		else:
@@ -144,10 +147,12 @@ class ConsoleError(Exception):
 
 if __name__ == '__main__':	
 	# Testing Demo
-	cons = Console()
+	cons = Console(Debug=False)
 
+	cons.Log("haha")
+	cons.Log("Wrote Something", "[ERROR] ", "red")
 	def func():
-		cons.WriteLine("Wrote Something")
+		cons.Log("Wrote Something")
 
 	def cl():
 		cons.Clear()
@@ -156,4 +161,6 @@ if __name__ == '__main__':
 	clear = Command("Clear", cl)
 	cons.RegisterCommand(cmd)
 	cons.RegisterCommand(clear)
-	tk.mainloop()
\ No newline at end of file
+	tk.mainloop()
+
+
